## 2.4.3 (2021-12-08)

Adjust opentracing return types for mocks (#6527)

## 2.4.2 (2021-12-03)

Fix minor issues in opentracing (#6482)

## 2.4.1 (2021-12-03)

Annotate remaining opentracing fields, arguments, and return types (#6476)

## 2.4.0 (2021-12-02)

Add opentracing stubs (#6473)

